| Title: | 'Rcpp' Bindings for 'Geiger' Header-Only Micro-Benchmark Framework |
|---|---|
| Description: | The 'Geiger' Header-Only C++11 Micro-Benchmarks Framework, written by David Grosss and released under the MIT license, is provided for use by R packages through lightweight integration with 'Rcpp'. |
| Authors: | Dirk Eddelbuettel |
| Maintainer: | Dirk Eddelbuettel <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.0.1.1 |
| Built: | 2026-05-20 09:27:26 UTC |
| Source: | https://github.com/eddelbuettel/rcppgeiger |
Simple microbenchmarking examples
simple() walk()simple() walk()
None